"""Init file"""
from .writer import video_write
